package TS::ARIBString::Gaiji;

use strict;

use constant GAIJI => {
	85 => [
		'㐂',    '亭',    '份',    '仿',    '侚',    '俉',    '傜',    '儞',    # 1-8
		'冼',    '',      '匇',    '卡',    '卬',    '詹',    '吉',    '呍',    # 9-16
		'咖',    '咜',    '咩',    '唎',    '啊',    '噲',    '囤',    '圳',    # 17-24
		'圴',    '塚',    '墀',    '姤',    '娣',    '婕',    '寬',    '﨑',    # 25-32
		'',      '庬',    '弴',    '彅',    '德',    '怗',    '恵',    '愰',    # 33-40
		'昤',    '曈',    '曙',    '曺',    '曻',    '栞',    '梁',             # 41-47

		'椑',    '椻',    '橅',    '檑',    '櫛',    '杞',    '杙',    '',      # 48-55
		'毱',    '泠',    '洮',    '海',    '涿',    '淊',    '淸',    '渚',    # 56-63
		'潞',    '濹',    '灤',    '熙',    '熙',    '煇',    '燁',    '爀',    # 64-71
		'玟',    '玨',    '珉',    '珖',    '琛',    '琡',    '琢',    '琦',    # 72-79
		'琪',    '琬',    '琹',    '瑋',    '',      '畵',    '疁',    '睲',    # 80-87
		'',      '磈',    '磠',    '祇',    '禮',    '',      '',               # 88-94
	],

	86 => [
		'',      '秚',    '稞',    '筿',    '簱',    '',      '綋',    '羡',    # 1-8
		'脘',    '脺',    '館',    '芮',    '葛',    '蓜',    '蓬',    '蕙',    # 9-16
		'藎',    '蝕',    '蟬',    '蠋',    '裵',    '角',    '諶',    '跎',    # 17-24
		'辻',    '迶',    '郝',    '鄧',    '鄭',    '醲',    '鈳',    '銈',    # 25-32
		'錡',    '鍈',    '閒',    '雞',    '餃',    '饀',    '髙',    '鯖',    # 33-40
		'鷗',    '麴',    '麵',    '',      '',      '',      '',               # 41-47

		'',      '',      '',      '',      '',      '',      '',      '',      # 48-55
		'',      '',      '',      '',      '',      '',      '',      '',      # 56-63
		'',      '',      '',      '',      '',      '',      '',      '',      # 64-71
		'',      '',      '',      '',      '',      '',      '',      '',      # 72-79
		'',      '',      '',      '',      '',      '',      '',      '',      # 80-87
		'',      '',      '',      '',      '',      '',      '',               # 88-94
	],

	90 => [
		'',      '',      '',      '',      '',      '',      '',      '',      # 1-8
		'',      '',      '',      '',      '',      '',      '',      '',      # 9-16
		'',      '',      '',      '',      '',      '',      '',      '',      # 17-24
		'▽',    '',      '☒',    '',      '',      '',      '',      '○',    # 25-32
		'(10)',  '(20)',  '(30)',  '(40)',  '(50)',  '(60)',  '(70)',  '(80)',  # 33-40
		'',      '',      '',      '',      '10.',   '11.',   '12.',            # 41-47

		'[HV]',  '[SD]',  '[P]',   '[W]',   '[MV]',  '[手]',  '[字]',  '[双]',  # 48-55
		'[デ]',  '[S]',   '[二]',  '[多]',  '[解]',  '[SS]',  '[B]',   '[N]',   # 56-63
		'■',    '●',    '[天]',  '[交]',  '[映]',  '[無]',  '[料]',  '[鍵]',  # 64-71
		'[前]',  '[後]',  '[再]',  '[新]',  '[初]',  '[終]',  '[生]',  '[販]',  # 72-79
		'[声]',  '[吹]',  '[PPV]', '(秘)',  'ほか',  '',      '',      '',      # 80-87
		'',      '',      '',      '',      '',      '',      '',               # 88-94
	],

	91 => [
		'',      '',      '◎',    '○',    '',      '×',    '(火)',  '〒',    # 1-8
		'',      '(文)',  '(幼)',  '',      '卍',    '',      '',      '∴',    # 9-16
		'♨',    '',      '',      '',      '',      '✈',    '▲',    '',      # 17-24
		'',      '',      '',      '',      '(H)',   '(D)',   '(S)',   '□',    # 25-32
		'(P)',   '[IC]',  '[SA]',  '[PA]',  '[J]',   '',      '',      '',      # 33-40
		'',      '[L]',   '℡',    '',      '',      '',      '',               # 41-47

		'[M]',   '',      '',      '',      '',      '',      '',      '',      # 48-55
		'',      '',      '',      '',      '',      '',      '',      '',      # 56-63
		'',      '',      '',      '',      '',      '',      '',      '',      # 64-71
		'',      '',      '',      '',      '',      '',      '',      '',      # 72-79
		'',      '',      '',      '',      '',      '',      '',      '',      # 80-87
		'',      '',      '',      '',      '',      '',      '',               # 88-94
	],

	92 => [
		'→',    '←',    '↑',    '↓',    '',      '',      '年',    '月',    # 1-8
		'日',    '円',    '㎡',    '㎥',    '㎝',    '㎠',    '㎤',    '0.',    # 9-16
		'1.',    '2.',    '3.',    '4.',    '5.',    '6.',    '7.',    '8.',    # 17-24
		'9.',    '氏',    '副',    '元',    '故',    '前',    '新',    '0,',    # 25-32
		'1,',    '2,',    '3,',    '4,',    '5,',    '6,',    '7,',    '8,',    # 33-40
		'9,',    '㈳',    '㈶',    '㈲',    '㈱',    '㈹',    '(問)',           # 41-47

		'▶',     '◀',     '〖',    '〗',    '',      '2',     '3',     '(CD)',  # 48-55
		'(vn)',  '(ob)',  '(cb)',  '(ce',   'mb)',   '(hp)',  '(br)',  '(p)',   # 56-63
		'(s)',   '(ms)',  '(t)',   '(bs)',  '(b)',   '(tb)',  '(tp)',  '(ds)',  # 64-71
		'(ag)',  '(eg)',  '(vo)',  '(fl)',  '(ke',   'y)',    '(sa',   'x)',    # 72-79
		'(sy',   'n)',    '(or',   'g)',    '(pe',   'r)',    '®',     '©',     # 80-87
		'(箏)',  'DJ',    '[演]',  'Fax',   '',      '',      '',               # 88-94
	],

	93 => [
		'㈪',    '㈫',    '㈬',    '㈭',    '㈮',    '㈯',    '㈰',    '㈷',    # 1-8
		'㍾',    '㍽',    '㍼',    '㍻',    '№',    '℡',    '〶',    '',      # 9-16
		'[本]',  '[三]',  '[二]',  '[安]',  '[点]',  '[打]',  '[盗]',  '[勝]',  # 17-24
		'[敗]',  '[S]',   '[投]',  '[補]',  '[一]',  '[二]',  '[三]',  '[遊]',  # 25-32
		'[左]',  '[中]',  '[右]',  '[指]',  '[走]',  '[打]',  'ℓ',     '㎏',    # 33-40
		'㎐',    '㏊',    '㎞',    '㎢',    '㍱',    '',      '',               # 41-47

		'1/2',   '0/3',   '1/3',   '2/3',   '1/4',   '3/4',   '1/5',   '2/5',   # 48-55
		'3/5',   '4/5',   '1/6',   '5/6',   '1/7',   '1/8',   '1/9',   '1/10',  # 56-63
		'☀',    '☁',    '☂',    '☃',    '',      '',      '',      '',      # 64-71
		'♦',     '♥',     '♣',     '♠',     '',      '☉',    '!!',    '!?',    # 72-79
		'',      '',      '',      '',      '',      '',      '',      '',      # 80-87
		'＞',    '＜',    '♬',     '☎',    '',      '',      '',               # 88-94
	],

	94 => [
		'Ⅰ',    'Ⅱ',    'Ⅲ',    'Ⅳ',    'Ⅴ',    'Ⅵ',    'Ⅶ',    'Ⅷ',    # 1-8
		'Ⅸ',    'Ⅹ',    'Ⅺ',    'Ⅻ',    '⑰',    '⑱',    '⑲',    '⑳',    # 9-16
		'⑴',    '⑵',    '⑶',    '⑷',    '⑸',    '⑹',    '⑺',    '⑻',    # 17-24
		'⑼',    '⑽',    '⑾',    '⑿',    '(21)',  '(22)',  '(23)',  '(24)',  # 25-32
		'(A)',   '(B)',   '(C)',   '(D)',   '(E)',   '(F)',   '(G)',   '(H)',   # 33-40
		'(I)',   '(J)',   '(K)',   '(L)',   '(M)',   '(N)',   '(O)',            # 41-47

		'(P)',   '(Q)',   '(R)',   '(S)',   '(T)',   '(U)',   '(V)',   '(W)',   # 48-55
		'(X)',   '(Y)',   '(Z)',   '(25)',  '(26)',  '(27)',  '(28)',  '(29)',  # 56-63
		'(30)',  '①',    '②',    '③',    '④',    '⑤',    '⑥',    '⑦',    # 64-71
		'⑧',    '⑨',    '⑩',    '⑪',    '⑫',    '⑬',    '⑭',    '⑮',    # 72-79
		'⑯',    '①',    '②',    '③',    '④',    '⑤',    '⑥',    '⑦',    # 80-87
		'⑧',    '⑨',    '⑩',    '⑪',    '⑫',    '(31)',  '',               # 88-94
	],
};

1;
